/*!
 * @license New BSD License
 * @copyright Copyright (c) 2010, Nokia Corporation
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *   * Neither the name of the Nokia Corporation nor the
 *     names of its contributors may be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NOKIA CORPORATION BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef GEOCRITERIA_H
#define GEOCRITERIA_H

#include <QList>

#include "GeoLocationInfo.h"


QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

class GeoCriteriaPrivate;

/*!
    \class GeoCriteria
    \brief The GeoCriteria class defines result's acceptance criteria for GeoFinder reverse geocoding  APIs.

    The GeoCriteria class defines result's acceptance criteria for GeoFinder reverse geocoding APIs.
    If GeoFinder results do not contain all address fields specified in the criteria 
    false will be returned with GeoFinder::onFinished() signal. Empty criteria with 
    no address fields added is always satisfied.
*/

class GeoCriteria : public QObject
{
    Q_OBJECT

public:
    /*!
    * Constructor.
    */
    GeoCriteria();

    /*!
    * Destructor.
    */
    ~GeoCriteria();

    /*!
    * Adds adress field as criteria. 
    * Criteria is satisfied if search results contain this field.
    */
    void add(GeoLocationInfo::AddressField field);

    /*!
    * Adds all adress fields as criteria. 
    * Criteria is satisfied if search results contain all GeoLocationInfo::AddressField fields.
    */
    void addAll();

    /*!
    * Removes adress field from criteria.
    */
    void remove(GeoLocationInfo::AddressField field);

    /*!
    * Clears the criteria so it accepts all results.
    */
    void clear();

    /*!
    * Gets all fields from the criteria.
    */
    QList<GeoLocationInfo::AddressField> getAll() const;

private:
    Q_DECLARE_PRIVATE(GeoCriteria)
    Q_DISABLE_COPY(GeoCriteria)
    GeoCriteriaPrivate *d_ptr;
};


QT_END_NAMESPACE

QT_END_HEADER

#endif // GEOCRITERIA_H


